This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] iq2000 and mn10300: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as obvious.

Kazu Hirata

2003-08-22  Kazu Hirata  <kazu@cs.umass.edu>

	* config/iq2000/iq2000.c: Follow spelling conventions.
	* config/iq2000/iq2000.h: Likewise.
	* config/mn10300/mn10300.c: Likewise.

Index: config/iq2000/iq2000.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/iq2000/iq2000.h,v
retrieving revision 1.3
diff -u -r1.3 iq2000.h
--- config/iq2000/iq2000.h	23 Aug 2003 01:32:54 -0000	1.3
+++ config/iq2000/iq2000.h	23 Aug 2003 02:47:47 -0000
@@ -1250,7 +1250,7 @@
 
 /* Certain machines have the property that some registers cannot be
    copied to some other registers without using memory.  Define this
-   macro on those machines to be a C expression that is non-zero if
+   macro on those machines to be a C expression that is nonzero if
    objects of mode MODE in registers of CLASS1 can only be copied to
    registers of class CLASS2 by storing a register of CLASS1 into
    memory and loading that memory location into a register of CLASS2.
Index: config/mn10300/mn10300.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/mn10300/mn10300.c,v
retrieving revision 1.55
diff -u -r1.55 mn10300.c
--- config/mn10300/mn10300.c	10 Jul 2003 04:50:15 -0000	1.55
+++ config/mn10300/mn10300.c	23 Aug 2003 02:47:48 -0000
@@ -695,7 +695,7 @@
 #define SIZE_FMOV_SP(S,N) (SIZE_FMOV_SP_ ((unsigned HOST_WIDE_INT)(S), (N)))
 
       /* Consider alternative save_sp_merge only if we don't need the
-	 frame pointer and size is non-zero.  */
+	 frame pointer and size is nonzero.  */
       if (! frame_pointer_needed && size)
 	{
 	  /* Insn: add -(size + 4 * num_regs_to_save), sp.  */
@@ -750,7 +750,7 @@
 	}
 
       /* Consider alternative save_a0_merge only if we don't need a
-	 frame pointer, size is non-zero and the user hasn't
+	 frame pointer, size is nonzero and the user hasn't
 	 changed the calling conventions of a0.  */
       if (! frame_pointer_needed && size
 	  && call_used_regs[FIRST_ADDRESS_REGNUM]
@@ -1855,7 +1855,7 @@
 }
 
 /* Return zero if X references a SYMBOL_REF or LABEL_REF whose symbol
-   isn't protected by a PIC unspec; non-zero otherwise.  */
+   isn't protected by a PIC unspec; nonzero otherwise.  */
 int
 legitimate_pic_operand_p (x)
      rtx x;


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: config/iq2000/iq2000.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/iq2000/iq2000.c,v
retrieving revision 1.2
diff -u -r1.2 iq2000.c
--- config/iq2000/iq2000.c	23 Aug 2003 01:32:54 -0000	1.2
+++ config/iq2000/iq2000.c	23 Aug 2003 02:47:47 -0000
@@ -420,7 +420,7 @@
 }
 
 /* Return a nonzero value if XINSN is a legitimate address for a
-   memory operand of the indicated MODE.  STRICT is non-zero if this
+   memory operand of the indicated MODE.  STRICT is nonzero if this
    function is called during reload.  */
 
 int
@@ -1195,7 +1195,7 @@
 	  test_code = NE;
 	}
       else if (GET_CODE (cmp1) == CONST_INT && INTVAL (cmp1) != 0)
 	/* We don't want to build a comparison against a non-zero
 	   constant.  */
 	cmp1 = force_reg (mode, cmp1);
 
@@ -2525,7 +2525,7 @@
   return compute_frame_size (get_frame_size ()) == 0;
 }
 
 /* Returns non-zero if X contains a SYMBOL_REF.  */
 
 static int
 symbolic_expression_p (rtx x)
@@ -2679,11 +2679,11 @@
    INSN is the branch instruction.  OPERANDS[0] is the condition.
    OPERANDS[1] is the target of the branch.  OPERANDS[2] is the target
    of the first operand to the condition.  If TWO_OPERANDS_P is
-   non-zero the comparison takes two operands; OPERANDS[3] will be the
+   nonzero the comparison takes two operands; OPERANDS[3] will be the
    second operand.
 
-   If INVERTED_P is non-zero we are to branch if the condition does
-   not hold.  If FLOAT_P is non-zero this is a floating-point comparison.
+   If INVERTED_P is nonzero we are to branch if the condition does
+   not hold.  If FLOAT_P is nonzero this is a floating-point comparison.
 
    LENGTH is the length (in bytes) of the sequence we are to generate.
    That tells us whether to generate a simple conditional branch, or a
@@ -2696,7 +2696,7 @@
   static char buffer[200];
   /* The kind of comparison we are doing.  */
   enum rtx_code code = GET_CODE (operands[0]);
   /* Non-zero if the opcode for the comparison needs a `z' indicating
      that it is a comparision against zero.  */
   int need_z_p;
   /* A string to use in the assembly output to represent the first
@@ -2721,7 +2721,7 @@
 	 subtract B from A and then look at the sign bit.  But, if we
 	 are doing an unsigned comparison, and B is zero, we don't
 	 have to do the subtraction.  Instead, we can just check to
-	 see if A is non-zero.  Thus, we change the CODE here to
+	 see if A is nonzero.  Thus, we change the CODE here to
 	 reflect the simpler comparison operation.  */
       switch (code)
 	{
@@ -1195,7 +1195,7 @@
 	}
       else if (GET_CODE (cmp1) == CONST_INT && INTVAL (cmp1) != 0)
-	/* We don't want to build a comparison against a non-zero
+	/* We don't want to build a comparison against a nonzero
 	   constant.  */
 	cmp1 = force_reg (mode, cmp1);
@@ -2525,7 +2525,7 @@
 }
 
-/* Returns non-zero if X contains a SYMBOL_REF.  */
+/* Returns nonzero if X contains a SYMBOL_REF.  */
 
 static int
@@ -2696,7 +2696,7 @@
   /* The kind of comparison we are doing.  */
   enum rtx_code code = GET_CODE (operands[0]);
-  /* Non-zero if the opcode for the comparison needs a `z' indicating
+  /* Nonzero if the opcode for the comparison needs a `z' indicating
      that it is a comparision against zero.  */
   int need_z_p;